<?php

if (!function_exists('joy_option')) {
	function joy_option($param, $default = '') {
		$value = get_theme_mod( $param, $default );
	
		if (has_filter('BRUNCH_DEMO_MODE')) {
			$value = apply_filters('BRUNCH_DEMO_MODE', $param, $value);
		}
	
		return $value;
	}
}


if ( ! function_exists( 'joy_post_classes' ) ) {

	function joy_post_classes( $classes ) {

		// Class indicating presence/lack of post thumbnail
		$classes[] = ( has_post_thumbnail() ? 'has-thumbnail' : 'missing-thumbnail' );

		return $classes;
	}
	add_action( 'post_class', 'joy_post_classes' );

}



if ( ! function_exists( 'joy_body_classes' ) ) {

	function joy_body_classes( $classes ) {

		// Check whether we're in the customizer preview
		if ( is_customize_preview() ) {
			$classes[] = 'customizer-preview';
		}

		// Check whether we want it darker
		if ( joy_option('color_mode', 'light' ) == 'dark' ) {
			$classes[] = 'dark-mode';
		}

		$classes[] = 'show-alt-nav';		

		if (joy_option ('blog_glow', false) == true) {
			$classes[] = 'glow-effect';
		}
		
		$classes[] = 'blog-3cols';
		
		// Check whether we're doing three preview columns
		if ( joy_option('blog_meta_visibility', 'always') == 'always' ) {
			$classes[] = 'show-preview-titles';
		}
		
		
		// featured size setup
		$setup_featured_size = joy_option('post_featured_size', 'default');
		if (is_single()) {
			$post_featured_size = joy_meta_value(get_the_ID(), 'layout');
			
			if ($post_featured_size != '' && $post_featured_size != 'settings_default') {
				$setup_featured_size = $post_featured_size;
			}
		}

		if ( $setup_featured_size == 'wide') {
			$classes[] = 'wide-featured-image';
		}
		
		if ( $setup_featured_size == 'vertical') {
			$classes[] = 'vertical-featured-image';
		}
		
		if (is_single() && joy_get_sidebar_setup() != 'no') {
			$classes[] = 'has-sidebar-'.joy_get_sidebar_setup();
		}
		
		if (!is_single() && joy_option('blog_sidebar', 'no') != 'no') {
			$classes[] = 'blog-sidebar-'.joy_option('blog_sidebar', 'no');
		}
		
		// Add short class to body if resumé page template
		if ( is_page_template( 'resume-page-template.php' ) ) {
			$classes[] = 'resume-template';
		}
		
		if ( is_page_template( 'wide-page-template.php' ) ) {
			$classes[] = 'wide-template';
		}
		
		if ( is_page_template( 'large-page-template.php' ) ) {
			$classes[] = 'large-template';
		}
		
		if (joy_option('wd_styles', 'classic') == 'modern') {
			$classes[] = 'widget-style2';
		}
		
		if (joy_option('blog_remove_fade', false) == true) {
			$classes[] = 'without-spotted-effect';
		}
		
		if (!joy_page_title_setup()) {
			$classes[] = 'hide-pagetitle';
		}
		
		return $classes;
	}
	add_action( 'body_class', 'joy_body_classes' );

}



if ( ! function_exists( 'joy_remove_archive_title_prefix' ) ) {

	function joy_remove_archive_title_prefix( $title ) {
		if ( is_category() ) {
			$title = single_cat_title( '', false );
		} elseif ( is_tag() ) {
			$title = single_tag_title( '#', false );
		} elseif ( is_author() ) {
			$title = '<span class="vcard">' . get_the_author() . '</span>';
		} elseif ( is_year() ) {
			$title = get_the_date( 'Y' );
		} elseif ( is_month() ) {
			$title = get_the_date( 'F Y' );
		} elseif ( is_day() ) {
			$title = get_the_date( get_option( 'date_format' ) );
		} elseif ( is_tax( 'post_format' ) ) {
			if ( is_tax( 'post_format', 'post-format-aside' ) ) {
				$title = _x( 'Asides', 'post format archive title', 'brunch-lite' );
			} elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
				$title = _x( 'Galleries', 'post format archive title', 'brunch-lite' );
			} elseif ( is_tax( 'post_format', 'post-format-image' ) ) {
				$title = _x( 'Images', 'post format archive title', 'brunch-lite' );
			} elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
				$title = _x( 'Videos', 'post format archive title', 'brunch-lite' );
			} elseif ( is_tax( 'post_format', 'post-format-quote' ) ) {
				$title = _x( 'Quotes', 'post format archive title', 'brunch-lite' );
			} elseif ( is_tax( 'post_format', 'post-format-link' ) ) {
				$title = _x( 'Links', 'post format archive title', 'brunch-lite' );
			} elseif ( is_tax( 'post_format', 'post-format-status' ) ) {
				$title = _x( 'Statuses', 'post format archive title', 'brunch-lite' );
			} elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
				$title = _x( 'Audio', 'post format archive title', 'brunch-lite' );
			} elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
				$title = _x( 'Chats', 'post format archive title', 'brunch-lite' );
			}
		} elseif ( is_post_type_archive() ) {
			$title = post_type_archive_title( '', false );
		} elseif ( is_tax() ) {
			$title = single_term_title( '', false );
		} else {
			$title = __( 'Archives', 'brunch-lite' );
		}
		return $title;
	}
	add_filter( 'get_the_archive_title', 'joy_remove_archive_title_prefix' );
}


function joy_convert_date( $orig_time ) {


	$time_arr = array(
			'minutes' => 60,
			'hours' => HOUR_IN_SECONDS,
			'days' => DAY_IN_SECONDS,
			'months' => YEAR_IN_SECONDS / 12,
	);

	$opts = array(
			'active'   => array( 'date' => true, 'time' => true ),
			'position' => 'after',
			'time'    => array( 'number' => '12', 'type'  => 'months' ),
			'ago_label' => ''
	);
	$time = current_time( 'timestamp' );

	$limit = (int)$opts['time']['number'] * $time_arr[$opts['time']['type']] ;

	global $post;
	$post_time = strtotime( $post->post_date );

	if ( ( $time - $post_time ) <= $limit ) {

		$ago_label = !empty( $opts['ago_label'] ) ? $opts['ago_label'] : esc_html__( 'ago', 'brunch-lite' );

		if ( $opts['position'] === 'after' ) {
			return human_time_diff( $post_time, $time ).' '.$ago_label;
		} else {
			return $ago_label.' '.human_time_diff( $post_time, $time );
		}

	}

	return $orig_time;

}

function joy_grid_category() {
	if (joy_option('blog_show_categories', true) == true) {
		$categories = get_the_category();
		if ( ! empty( $categories ) ) {
			echo '<span class="cat-links">';
			echo esc_html__('Posted in', 'brunch-lite') . ' ' . '<a href="' . esc_url( get_category_link( $categories[0]->term_id ) ) . '">'.esc_html( $categories[0]->name ).'</a>';
			echo '</span>';
		}
	}
}

function joy_grid_additional_meta() {
	
	if (joy_option('blog_show_author', true) == true) {
		//echo '<span class="bull-space">, </span>';
		echo sprintf( '<span class="author vcard">'.esc_html__('by', 'brunch-lite').' '.'<a class="url fn n" href="%1$s">%2$s</a></span>', esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ), esc_html( get_the_author() ) );
	}
	
	if (joy_option('blog_show_posted', true) == true) {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="updated" datetime="%3$s">%4$s</time>';
		}
		
		$time_string = sprintf( $time_string,
				esc_attr( get_the_date( 'c' ) ),
				esc_html( get_the_date() ),
				esc_attr( get_the_modified_date( 'c' ) ),
				esc_html( get_the_modified_date() )
		);
		
		if (joy_option('time_ago', false) == true) {
			$time_string = joy_convert_date(get_the_time());
		}
		
		echo '<span class="bull-space"></span>';
		echo '<span class="posted-on">'.esc_html__(',', 'brunch-lite').' '.$time_string.'</span>';
	}
	
	if (joy_option('blog_recipe_meta', false) == true) {
		$recipe_data = array();
		$recipe_data['totaltime'] = get_post_meta( get_the_ID(), 'pb_recipe_totaltime', true );
		$recipe_data['yields'] = get_post_meta( get_the_ID(), 'pb_recipe_yields', true );
		$recipe_data['cookingmethod'] = get_post_meta( get_the_ID(), 'pb_recipe_cooking_method', true );
		$recipe_data['cuisine'] = get_post_meta( get_the_ID(), 'pb_recipe_cuisine', true );
		
		if ($recipe_data['totaltime'] != '') {
			echo '<span class="bull-space"></span>';
			echo '<span class="posted-on">'.esc_html__(',', 'brunch-lite').' '.esc_html__('Ready in', 'brunch-lite').' '.joy_format_time($recipe_data['totaltime']).'</span>';
		}
		if ($recipe_data['yields'] != '') {
			echo '<span class="bull-space"></span>';
			echo '<span class="posted-on">'.esc_html__(',', 'brunch-lite').' '.esc_html__('Yields:', 'brunch-lite').' '.($recipe_data['yields']).'</span>';
		}
	}
}

function joy_single_entry_additional_meta() {
	if (joy_option('post_show_author', true) == true) {
		echo '<span class="bull">&bull;</span>';
		echo __( 'By', 'brunch-lite' ) . ' ' . sprintf( '<a class="url fn n" href="%1$s">%2$s</a>', esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ), esc_html( get_the_author() ) );
	}
	
	if (joy_option('post_show_posted', true) == true) {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="updated" datetime="%3$s">%4$s</time>';
		}
			
		$time_string = sprintf( $time_string,
				esc_attr( get_the_date( 'c' ) ),
				esc_html( get_the_date() ),
				esc_attr( get_the_modified_date( 'c' ) ),
				esc_html( get_the_modified_date() )
		);
			
		if (joy_option('time_ago', false) == true) {
			
			$time_string = joy_convert_date(get_the_time());
		}
			
		echo '<span class="bull">&bull;</span>';
		echo sprintf( '<a href="%1$s" rel="bookmark">%2$s</a>', esc_url( get_permalink() ), $time_string );
	}

	if (joy_option('blog_show_time', true) == true) {
		$words_per_minute = joy_option('blog_show_time_words', '250');
	
		$content = get_post_field( 'post_content', get_the_ID() );
		$word_count = str_word_count( strip_tags( $content ) );
		if ($words_per_minute != '') {
			$ttr = round($word_count / $words_per_minute);
		}
		else {
			$ttr = round($word_count / 250);
		}
	
		if ($ttr == 0 ){
			$ttr = '1';
		}
	
		echo '<span class="bull">&bull;</span>';
		echo  '<span class="time-to-read">'.$ttr.' '.esc_html__('Min', 'brunch-lite').' ' . esc_html__('Read', 'brunch-lite'). '</span></span>';
	}
}

function joy_get_the_date() {
	$time_string = ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) ? get_the_modified_date() : get_the_date();
	if (joy_option('time_ago', false) == true) {
		$time_string = joy_convert_date(get_the_time());
	}

	return $time_string;
}

function joy_single_entry_categories() {
	if ( 'post' == get_post_type() ) {

			$categories_list = get_the_category_list( esc_html__( ' ', 'brunch-lite' ) );
			if ( $categories_list  ) {
				printf( '<span class="cat-links cat-links-single">%1$s</span>', $categories_list );
			}
	}
}

function joy_get_prev_next_posts() {

	$prev = get_adjacent_post( true, '', false, 'category' );
	$next = get_adjacent_post( true, '', true, 'category' );

	return array( 'prev' => $prev, 'next' => $next );

}

function joy_background_lazyload_class() {

	$class_name = '';

	if (joy_option('image_lazyload', false) == true) {
		$class_name = 'background_lazy';

	}

	if ($class_name != '') {
		echo $class_name;
	}
}

function joy_get_image_lazyload_class() {
	$class_name = '';

	if (joy_option('image_lazyload', false) == true) {
		$class_name = 'image_lazy';
	}

	return $class_name;
}

function joy_background_image($image_url) {
	if (joy_option('image_lazyload', false) == true) {
		echo 'data-background="'.esc_url($image_url).'"';
	}
	else {
		echo 'style="background-image: url('.esc_url($image_url).');"';
	}
}

function joy_get_background_image($image_url) {
	if (joy_option('image_lazyload', false) == true) {
		return 'data-background="'.esc_url($image_url).'"';
	}
	else {
		return 'style="background-image: url('.esc_url($image_url).');"';
	}
}

function joy_meta_value($id, $param) {
	$value = get_post_meta( $id, 'pb_'.$param, true );

	return $value;
}

function joy_has_post_gallery($id, $param) {
	$values = get_post_meta($id);

	$has_gallery = false;

	return array('active' => $has_gallery, 'gallery' => $has_gallery ? $values['pb_'.$param] : array());
}

function joy_get_sidebar_setup() {
	$settings_sidebar = joy_option('post_sidebar', 'no');
	
	if (is_single()) {
		$post_sidebar = joy_meta_value(get_the_ID(), 'post_sidebar_pos');
		
		if ($post_sidebar != '' && $post_sidebar != 'default') {
			$settings_sidebar = $post_sidebar;
		}
	}
	
	return $settings_sidebar;
}

function joy_page_title_setup() {
	$display = true;
	if (is_singular('page')) {
		if (joy_meta_value(get_the_ID(), 'page_title') == 'hide') {
			$display = false;
		}
	}
	
	return $display;
}

if (BRUNCH_DEMO_MODE) {
	add_action( 'pre_get_posts', 'joy_demo_posts_count', 1 );

	function joy_demo_posts_count($query) {
		if ( is_admin() || ! $query->is_main_query() )
			return;

		$joy_count = isset($_REQUEST['post_count']) ? $_REQUEST['post_count'] : '';

		if ($joy_count != '' && intval($joy_count) != 0) {
			$query->set( 'posts_per_page', intval($joy_count) );
		}
	}

	add_filter('BRUNCH_DEMO_MODE', 'BRUNCH_DEMO_MODE', 10, 2);

	function BRUNCH_DEMO_MODE($option, $value) {

		if (isset($_REQUEST[$option])) {
			$query_value = $_REQUEST[$option];

			if ($query_value == 'true' || $query_value == 'false') {
				if ($query_value == 'true') {
					$value = true;
				}
				else {
					$value = false;
				}
			}
			else {
				$value = $query_value;
			}
		}

		return $value;
	}
}

function joy_set_dropcap($content) {
	
	if (!is_singular('post')) {
		return $content;
	}
	
	if ( preg_match( '#(^)(?:\s?)*(([A-Z]|[a-z]|[0-9]|[\p{L}])(.*\R)*(\R)*.*)#m', $content, $matches ) ) {
	
		$top_content = str_replace( $matches[2], '', $content );
	
		$bottom_content = ltrim( $matches[2] );
	
		$joy_first_letter_of_filtered_content = mb_substr( $bottom_content, 0, 1 );
	
		if (joy_option('dropcap_style', 'style1') == 'style1' || joy_option('dropcap_style', 'style1') == 'style3') {
			if ( mb_substr( $bottom_content, 1, 1 ) === ' ' ) {
				$joy_remaining_letters_of_filtered_content = ' ' . mb_substr( $bottom_content, 2 );
			} else {
				$joy_remaining_letters_of_filtered_content = mb_substr( $bottom_content, 1);
			}
		}
		else {
			$joy_remaining_letters_of_filtered_content = $content;
		}
	
		$joy_dropcapped_first_letter = '<span class="dropcap dropcap-'.joy_option('dropcap_style', 'style1').'">' . $joy_first_letter_of_filtered_content . '</span>';
	
		$bottom_content = $joy_dropcapped_first_letter . $joy_remaining_letters_of_filtered_content;
	
		return $top_content . $bottom_content;
	}
	return $content;
	
}


function joy_get_featured_posts() {
	if (joy_option('header_featured', false) == true && joy_option('header_featured_tag', '') != '') {
		$settings = array('tag_name' => joy_option('header_featured_tag', ''));

		$user_count = joy_option('header_featured_count', '');
		if ($user_count != '' && intval($user_count) != 0) {
			$settings['max_posts'] = $user_count;
		}

		$settings['post_order'] = 'date';

		JoyFeaturedContent::setup($settings);
		$joy_featured = JoyFeaturedContent::get_featured_posts();

		return apply_filters( 'joy_get_featured_posts', $joy_featured );
	}
	else {
		return apply_filters( 'joy_get_featured_posts', false );
	}
}


function joy_format_time($minutes) {
	$minutes = intval($minutes);

	$output = array();

	if ($minutes < 60) {
		$output['time'] = '00:'.sprintf("%02d", $minutes);
	}
	else {
		$hours = floor($minutes / 60);
		$minutes = $minutes - ($hours * 60);

		$output['time'] = sprintf("%02d", $hours).':'.sprintf("%02d", $minutes);
	}

	return $output['time'];
}

function joy_categories_filter( $type ) {

	if ($type == 'index') {

		$categories_list = get_categories( array(
				'orderby' => 'name',
				'order'   => 'ASC'
		) );

		if ( ! empty( $categories_list ) && ! is_wp_error( $categories_list ) ) {

			$categories_list_display = '<ul class="category-filter">';

			if (! is_archive()) {

				$count_all_posts = wp_count_posts('post','readable');
				$categories_list_display .= '<li class="cat-active"><a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html__( 'All Stories', 'brunch-lite' ) . '<span>' . $count_all_posts->publish . '</span></a></li>';

				foreach( $categories_list as $category ) {
					$count = $category->category_count;
					$category_link = get_category_link( $category );
					$categories_list_display .= '<li><a href="' . esc_url( $category_link ) . '">' . esc_attr($category->name) . '<span>' . esc_attr($count) . '</span></a></li>';

				}

			} else {
				if ( isset( get_queried_object()->term_id ) ) {
					$category_id = get_queried_object()->term_id;
				} else {
					$category_id = 0;
				}

				$count_all_posts = wp_count_posts('post','readable');
				$categories_list_display .= '<li><a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html__( 'All Stories', 'brunch-lite' ) . '<span>' . esc_attr($count_all_posts->publish) . '</span></a></li>';

				foreach( $categories_list as $category ) {
					if ( $category->term_id == $category_id ) {
						$active_class = 'cat-active';
					} else {
						$active_class = '';
					}

					$count = $category->category_count;
					$category_link = get_category_link( $category );
					$categories_list_display .= '<li class="' . $active_class . '"><a href="' . esc_url( $category_link ) . '">' . esc_attr($category->name) . '<span>' . esc_attr($count) . '</span></a></li>';

				}
			}

			$categories_list_display .= '</ul>';

			print_r($categories_list_display);
		}
	}
}

function joy_social_profiles() {
	global $joy_social_apis;
	
	$existing_profiles = array();
	
	foreach ($joy_social_apis as $network => $network_name) {
		$profile_url = joy_option('social_'.$network, '');
		
		if ($profile_url != '') {
			$existing_profiles[] = array('network' => $network_name, 'url' => $profile_url);
		}
	}
	
	if (count($existing_profiles) > 0) {
		echo '<ul class="topbar-social">';
		echo '<li class="social-followus">'.__('Follow', 'brunch-lite').'</li>';
		foreach ($existing_profiles as $profile) {
			echo '<li><a href="'.$profile['url'].'" rel="nofollow" target="_blank">'.$profile['network'].'</a></li>';
		}
		
		echo '</ul>';
	}
}