<?php

add_filter ( 'the_content', 'joy_prepare_images', 12 );
add_filter ( 'post_thumbnail_html', 'joy_prepare_images' );

function joy_prepare_images( $content ) {
		/* No lazy images? */
		if ( strpos( $content, '-image' ) === false ) {
			return $content;
		}

		/* Replace images */
		return preg_replace_callback(
			'/(?P<all>                                                              (?# match the whole img tag )
				<img(?P<before>[^>]*)                                               (?# the opening of the img and some optional attributes )
				(                                                                   (?# match a class attribute followed by some optional ones and the src attribute )
					class=["\'](?P<class1>.*?(?:wp-image-|wp-post-image)[^>"\']*)["\']
					(?P<between1>[^>]*)
					src=["\'](?P<src1>[^>"\']*)["\']
					|                                                               (?# match same as before, but with the src attribute before the class attribute )
					src=["\'](?P<src2>[^>"\']*)["\']
					(?P<between2>[^>]*)
					class=["\'](?P<class2>.*?(?:wp-image-|wp-post-image)[^>"\']*)["\']
				)
				(?P<after>[^>]*)                                                    (?# match any additional optional attributes )
				(?P<closing>\/?)>                                                   (?# match the closing of the img tag with or without a self closing slash )
			)/x',
			'joy_replace_images',
			$content
		);
	}

	/**
	 * The callback function for the preg_match_callback to modify the img tags.
	 *
	 * @since   1.0.0
	 *
	 * @param array $matches The regex matches.
	 *
	 * @return string The modified content string.
	 */
	function joy_replace_images( $matches ) {
		/* Empty gif */
		$null = 'data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==';
		// Return unmodified image if the "data skip" attribute was found or the image has already been processed.
		if ( false !== strpos( $matches['all'], 'data-image-lazy="exclude"' ) || false !== strpos( $matches['class1'] . $matches['class2'], 'crazy_lazy' ) ) {
			return $matches['all'];
		} else {
            return '<img ' . $matches['before']
                   . ' style="display:none" '
                   . ' class="image_lazy ' . $matches['class1'] . $matches['class2'] . '" src="' . $null . '" '
                   . $matches['between1'] . $matches['between2']
                   . ' data-src="' . $matches['src1'] . $matches['src2'] . '" '
                   . $matches['after']
                   . $matches['closing'] . '><noscript>' . $matches['all'] . '</noscript>';
		}
	}
