<?php
/**
 * An example file demonstrating how to add all controls.
 *
 * @package     Kirki
 * @category    Core
 * @author      Aristeides Stathopoulos
 * @copyright   Copyright (c) 2017, Aristeides Stathopoulos
 * @license     http://opensource.org/licenses/https://opensource.org/licenses/MIT
 * @since       3.0.12
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Do not proceed if Kirki does not exist.
if ( ! class_exists( 'Kirki' ) ) {
	return;
}

/**
 * First of all, add the config.
 *
 * @link https://aristath.github.io/kirki/docs/getting-started/config.html
 */
Kirki::add_config( 'kirki_demo', array(
	'capability'  => 'edit_theme_options',
	'option_type' => 'theme_mod',
) );

/**
 * Add a panel.
 *
 * @link https://aristath.github.io/kirki/docs/getting-started/panels.html
 */
Kirki::add_panel( 'kirki_demo_panel', array(
	'priority'    => 10,
	'title'       => esc_attr__( 'Kirki Demo Panel', 'brunch-lite' ),
	'description' => esc_attr__( 'Contains sections for all kirki controls.', 'brunch-lite' ),
) );

/**
 * Add Sections.
 *
 * We'll be doing things a bit differently here, just to demonstrate an example.
 * We're going to define 1 section per control-type just to keep things clean and separate.
 *
 * @link https://aristath.github.io/kirki/docs/getting-started/sections.html
 */
$sections = array(
	'background'      => array( esc_attr__( 'Background', 'brunch-lite' ), '' ),
	'code'            => array( esc_attr__( 'Code', 'brunch-lite' ), '' ),
	'checkbox'        => array( esc_attr__( 'Checkbox', 'brunch-lite' ), '' ),
	'color'           => array( esc_attr__( 'Color', 'brunch-lite' ), '' ),
	'color-palette'   => array( esc_attr__( 'Color Palette', 'brunch-lite' ), '' ),
	'custom'          => array( esc_attr__( 'Custom', 'brunch-lite' ), '' ),
	'dashicons'       => array( esc_attr__( 'Dashicons', 'brunch-lite' ), '' ),
	'date'            => array( esc_attr__( 'Date', 'brunch-lite' ), '' ),
	'dimension'       => array( esc_attr__( 'Dimension', 'brunch-lite' ), '' ),
	'dimensions'      => array( esc_attr__( 'Dimensions', 'brunch-lite' ), '' ),
	'editor'          => array( esc_attr__( 'Editor', 'brunch-lite' ), '' ),
	'fontawesome'     => array( esc_attr__( 'Font-Awesome', 'brunch-lite' ), '' ),
	'generic'         => array( esc_attr__( 'Generic', 'brunch-lite' ), '' ),
	'image'           => array( esc_attr__( 'Image', 'brunch-lite' ), '' ),
	'multicheck'      => array( esc_attr__( 'Multicheck', 'brunch-lite' ), '' ),
	'multicolor'      => array( esc_attr__( 'Multicolor', 'brunch-lite' ), '' ),
	'number'          => array( esc_attr__( 'Number', 'brunch-lite' ), '' ),
	'palette'         => array( esc_attr__( 'Palette', 'brunch-lite' ), '' ),
	'preset'          => array( esc_attr__( 'Preset', 'brunch-lite' ), '' ),
	'radio'           => array( esc_attr__( 'Radio', 'brunch-lite' ), esc_attr__( 'A plain Radio control.', 'brunch-lite' ) ),
	'radio-buttonset' => array( esc_attr__( 'Radio Buttonset', 'brunch-lite' ), esc_attr__( 'Radio-Buttonset controls are essentially radio controls with some fancy styling to make them look cooler.', 'brunch-lite' ) ),
	'radio-image'     => array( esc_attr__( 'Radio Image', 'brunch-lite' ), esc_attr__( 'Radio-Image controls are essentially radio controls with some fancy styles to use images', 'brunch-lite' ) ),
	'repeater'        => array( esc_attr__( 'Repeater', 'brunch-lite' ), '' ),
	'select'          => array( esc_attr__( 'Select', 'brunch-lite' ), '' ),
	'slider'          => array( esc_attr__( 'Slider', 'brunch-lite' ), '' ),
	'sortable'        => array( esc_attr__( 'Sortable', 'brunch-lite' ), '' ),
	'switch'          => array( esc_attr__( 'Switch', 'brunch-lite' ), '' ),
	'toggle'          => array( esc_attr__( 'Toggle', 'brunch-lite' ), '' ),
	'typography'      => array( esc_attr__( 'Typography', 'brunch-lite' ), '' ),
);
foreach ( $sections as $section_id => $section ) {
	Kirki::add_section( str_replace( '-', '_', $section_id ) . '_section', array(
		'title'       => $section[0],
		'description' => $section[1],
		'panel'       => 'kirki_demo_panel',
	) );
}

/**
 * Background Control.
 *
 * @todo Triggers change on load.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'background',
	'settings'    => 'background_setting',
	'label'       => esc_attr__( 'Background Control', 'brunch-lite' ),
	'description' => esc_attr__( 'Background conrols are pretty complex! (but useful if properly used)', 'brunch-lite' ),
	'section'     => 'background_section',
	'default'     => array(
		'background-color'      => 'rgba(20,20,20,.8)',
		'background-image'      => '',
		'background-repeat'     => 'repeat-all',
		'background-position'   => 'center center',
		'background-size'       => 'cover',
		'background-attachment' => 'scroll',
	),
) );

/**
 * Code control.
 *
 * @link https://aristath.github.io/kirki/docs/controls/code.html
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'code',
	'settings'    => 'code_setting',
	'label'       => esc_attr__( 'Code Control', 'brunch-lite' ),
	'description' => esc_attr__( 'Description', 'brunch-lite' ),
	'section'     => 'code_section',
	'default'     => '',
	'choices'     => array(
		'language' => 'css',
		'theme'    => 'monokai',
	),
) );

/**
 * Checkbox control.
 *
 * @link https://aristath.github.io/kirki/docs/controls/checkbox.html
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'checkbox',
	'settings'    => 'checkbox_setting',
	'label'       => esc_attr__( 'Checkbox Control', 'brunch-lite' ),
	'description' => esc_attr__( 'Description', 'brunch-lite' ),
	'section'     => 'checkbox_section',
	'default'     => true,
) );

/**
 * Color Controls.
 *
 * @link https://aristath.github.io/kirki/docs/controls/color.html
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'color',
	'settings'    => 'color_setting_hex',
	'label'       => __( 'Color Control (hex-only)', 'brunch-lite' ),
	'description' => esc_attr__( 'This is a color control - without alpha channel.', 'brunch-lite' ),
	'section'     => 'color_section',
	'default'     => '#0088CC',
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'color',
	'settings'    => 'color_setting_rgba',
	'label'       => __( 'Color Control (with alpha channel)', 'brunch-lite' ),
	'description' => esc_attr__( 'This is a color control - with alpha channel.', 'brunch-lite' ),
	'section'     => 'color_section',
	'default'     => '#0088CC',
	'choices'     => array(
		'alpha' => true,
	),
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'color',
	'settings'    => 'color_setting_hue',
	'label'       => __( 'Color Control - hue only.', 'brunch-lite' ),
	'description' => esc_attr__( 'This is a color control - hue only.', 'brunch-lite' ),
	'section'     => 'color_section',
	'default'     => '#0088CC',
	'mode'        => 'hue',
) );

/**
 * DateTime Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'date',
	'settings'    => 'date_setting',
	'label'       => esc_attr__( 'Date Control', 'brunch-lite' ),
	'description' => esc_attr__( 'This is a date control.', 'brunch-lite' ),
	'section'     => 'date_section',
	'default'     => '',
) );

/**
 * Editor Controls
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'editor',
	'settings'    => 'editor_1',
	'label'       => esc_attr__( 'First Editor Control', 'brunch-lite' ),
	'description' => esc_attr__( 'This is an editor control.', 'brunch-lite' ),
	'section'     => 'editor_section',
	'default'     => '',
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'editor',
	'settings'    => 'editor_2',
	'label'       => esc_attr__( 'Second Editor Control', 'brunch-lite' ),
	'description' => esc_attr__( 'This is a 2nd editor control just to check that we do not have issues with multiple instances.', 'brunch-lite' ),
	'section'     => 'editor_section',
	'default'     => esc_attr__( 'Default Text', 'brunch-lite' ),
) );

/**
 * Color-Palette Controls.
 *
 * @link https://aristath.github.io/kirki/docs/controls/color-palette.html
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'color-palette',
	'settings'    => 'color_palette_setting_0',
	'label'       => esc_attr__( 'Color-Palette', 'brunch-lite' ),
	'description' => esc_attr__( 'This is a color-palette control', 'brunch-lite' ),
	'section'     => 'color_palette_section',
	'default'     => '#888888',
	'choices'     => array(
		'colors' => array( '#000000', '#222222', '#444444', '#666666', '#888888', '#aaaaaa', '#cccccc', '#eeeeee', '#ffffff' ),
		'style'  => 'round',
	),
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'color-palette',
	'settings'    => 'color_palette_setting_4',
	'label'       => esc_attr__( 'Color-Palette', 'brunch-lite' ),
	'description' => esc_attr__( 'Material Design Colors - all', 'brunch-lite' ),
	'section'     => 'color_palette_section',
	'default'     => '#F44336',
	'choices'     => array(
		'colors' => Kirki_Helper::get_material_design_colors( 'all' ),
		'size'   => 17,
	),
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'color-palette',
	'settings'    => 'color_palette_setting_1',
	'label'       => esc_attr__( 'Color-Palette', 'brunch-lite' ),
	'description' => esc_attr__( 'Material Design Colors - primary', 'brunch-lite' ),
	'section'     => 'color_palette_section',
	'default'     => '#000000',
	'choices'     => array(
		'colors' => Kirki_Helper::get_material_design_colors( 'primary' ),
		'size'   => 25,
	),
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'color-palette',
	'settings'    => 'color_palette_setting_2',
	'label'       => esc_attr__( 'Color-Palette', 'brunch-lite' ),
	'description' => esc_attr__( 'Material Design Colors - red', 'brunch-lite' ),
	'section'     => 'color_palette_section',
	'default'     => '#FF1744',
	'choices'     => array(
		'colors' => Kirki_Helper::get_material_design_colors( 'red' ),
		'size'   => 16,
	),
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'color-palette',
	'settings'    => 'color_palette_setting_3',
	'label'       => esc_attr__( 'Color-Palette', 'brunch-lite' ),
	'description' => esc_attr__( 'Material Design Colors - A100', 'brunch-lite' ),
	'section'     => 'color_palette_section',
	'default'     => '#FF80AB',
	'choices'     => array(
		'colors' => Kirki_Helper::get_material_design_colors( 'A100' ),
		'size'   => 60,
		'style'  => 'round',
	),
) );

/**
 * Dashicons control.
 *
 * @link https://aristath.github.io/kirki/docs/controls/dashicons.html
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'dashicons',
	'settings'    => 'dashicons_setting_0',
	'label'       => esc_attr__( 'Dashicons Control', 'brunch-lite' ),
	'description' => esc_attr__( 'Using a custom array of dashicons', 'brunch-lite' ),
	'section'     => 'dashicons_section',
	'default'     => 'menu',
	'choices'     => array(
		'menu',
		'admin-site',
		'dashboard',
		'admin-post',
		'admin-media',
		'admin-links',
		'admin-page',
	),
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'dashicons',
	'settings'    => 'dashicons_setting_1',
	'label'       => esc_attr__( 'All Dashicons', 'brunch-lite' ),
	'description' => esc_attr__( 'Showing all dashicons', 'brunch-lite' ),
	'section'     => 'dashicons_section',
	'default'     => 'menu',
) );

/**
 * Dimension Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'dimension',
	'settings'    => 'dimension_0',
	'label'       => esc_attr__( 'Dimension Control', 'brunch-lite' ),
	'description' => esc_attr__( 'Description Here.', 'brunch-lite' ),
	'section'     => 'dimension_section',
	'default'     => '10px',
) );

/**
 * Dimensions Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'dimensions',
	'settings'    => 'dimensions_0',
	'label'       => esc_attr__( 'Dimension Control', 'brunch-lite' ),
	'description' => esc_attr__( 'Description Here.', 'brunch-lite' ),
	'section'     => 'dimensions_section',
	'default'     => array(
		'width'  => '100px',
		'height' => '100px',
	),
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'dimensions',
	'settings'    => 'dimensions_1',
	'label'       => esc_attr__( 'Dimension Control', 'brunch-lite' ),
	'description' => esc_attr__( 'Description Here.', 'brunch-lite' ),
	'section'     => 'dimensions_section',
	'default'     => array(
		'padding-top'    => '1em',
		'padding-bottom' => '10rem',
		'padding-left'   => '1vh',
		'padding-right'  => '10px',
	),
) );

/**
 * Font-Awesome Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'fontawesome',
	'settings'    => 'fontawesome_setting',
	'label'       => esc_attr__( 'Font Awesome Control', 'brunch-lite' ),
	'description' => esc_attr__( 'Description Here.', 'brunch-lite' ),
	'section'     => 'fontawesome_section',
	'default'     => 'bath',
) );

/**
 * Generic Controls.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'text',
	'settings'    => 'generic_text_setting',
	'label'       => esc_attr__( 'Text Control', 'brunch-lite' ),
	'description' => esc_attr__( 'Description', 'brunch-lite' ),
	'section'     => 'generic_section',
	'default'     => '',
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'textarea',
	'settings'    => 'generic_textarea_setting',
	'label'       => esc_attr__( 'Textarea Control', 'brunch-lite' ),
	'description' => esc_attr__( 'Description', 'brunch-lite' ),
	'section'     => 'generic_section',
	'default'     => '',
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'generic',
	'settings'    => 'generic_custom_setting',
	'label'       => esc_attr__( 'Custom input Control.', 'brunch-lite' ),
	'description' => esc_attr__( 'The "generic" control allows you to add any input type you want. In this case we use type="password" and define custom styles.', 'brunch-lite' ),
	'section'     => 'generic_section',
	'default'     => '',
	'choices'     => array(
		'element'  => 'input',
		'type'     => 'password',
		'style'    => 'background-color:black;color:red;',
		'data-foo' => 'bar',
	),
) );

/**
 * Image Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'image',
	'settings'    => 'image_setting_url',
	'label'       => esc_attr__( 'Image Control (URL)', 'brunch-lite' ),
	'description' => esc_attr__( 'Description Here.', 'brunch-lite' ),
	'section'     => 'image_section',
	'default'     => '',
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'image',
	'settings'    => 'image_setting_id',
	'label'       => esc_attr__( 'Image Control (ID)', 'brunch-lite' ),
	'description' => esc_attr__( 'Description Here.', 'brunch-lite' ),
	'section'     => 'image_section',
	'default'     => '',
	'choices'     => array(
		'save_as' => 'id',
	),
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'image',
	'settings'    => 'image_setting_array',
	'label'       => esc_attr__( 'Image Control (array)', 'brunch-lite' ),
	'description' => esc_attr__( 'Description Here.', 'brunch-lite' ),
	'section'     => 'image_section',
	'default'     => '',
	'choices'     => array(
		'save_as' => 'array',
	),
) );

/**
 * Multicheck Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'multicheck',
	'settings'    => 'multicheck_setting',
	'label'       => esc_attr__( 'Multickeck Control', 'brunch-lite' ),
	'section'     => 'multicheck_section',
	'default'     => array( 'option-1', 'option-3', 'option-4' ),
	'priority'    => 10,
	'choices'     => array(
		'option-1' => esc_attr__( 'Option 1', 'brunch-lite' ),
		'option-2' => esc_attr__( 'Option 2', 'brunch-lite' ),
		'option-3' => esc_attr__( 'Option 3', 'brunch-lite' ),
		'option-4' => esc_attr__( 'Option 4', 'brunch-lite' ),
		'option-5' => esc_attr__( 'Option 5', 'brunch-lite' ),
	),
) );

/**
 * Multicolor Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'multicolor',
	'settings'    => 'multicolor_setting',
	'label'       => esc_attr__( 'Label', 'brunch-lite' ),
	'section'     => 'multicolor_section',
	'priority'    => 10,
	'choices'     => array(
		'link'    => esc_attr__( 'Color', 'brunch-lite' ),
		'hover'   => esc_attr__( 'Hover', 'brunch-lite' ),
		'active'  => esc_attr__( 'Active', 'brunch-lite' ),
	),
	'default'     => array(
		'link'    => '#0088cc',
		'hover'   => '#00aaff',
		'active'  => '#00ffff',
	),
) );

/**
 * Number Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'number',
	'settings'    => 'number_setting',
	'label'       => esc_attr__( 'Label', 'brunch-lite' ),
	'section'     => 'number_section',
	'priority'    => 10,
	'choices'     => array(
		'min'  => -5,
		'max'  => 5,
		'step' => 1,
	),
) );

/**
 * Palette Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'palette',
	'settings'    => 'palette_setting',
	'label'       => esc_attr__( 'Label', 'brunch-lite' ),
	'section'     => 'palette_section',
	'default'     => 'blue',
	'choices'     => array(
		'a200'  => Kirki_Helper::get_material_design_colors( 'A200' ),
		'blue'  => Kirki_Helper::get_material_design_colors( 'blue' ),
		'green' => array( '#E8F5E9', '#C8E6C9', '#A5D6A7', '#81C784', '#66BB6A', '#4CAF50', '#43A047', '#388E3C', '#2E7D32', '#1B5E20', '#B9F6CA', '#69F0AE', '#00E676', '#00C853' ),
		'bnw'   => array( '#000000', '#ffffff' ),
	),
) );

/**
 * Radio Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'radio',
	'settings'    => 'radio_setting',
	'label'       => esc_attr__( 'Radio Control', 'brunch-lite' ),
	'description' => esc_attr__( 'The description here.', 'brunch-lite' ),
	'section'     => 'radio_section',
	'default'     => 'option-3',
	'choices'     => array(
		'option-1' => esc_attr__( 'Option 1', 'brunch-lite' ),
		'option-2' => esc_attr__( 'Option 2', 'brunch-lite' ),
		'option-3' => esc_attr__( 'Option 3', 'brunch-lite' ),
		'option-4' => esc_attr__( 'Option 4', 'brunch-lite' ),
		'option-5' => esc_attr__( 'Option 5', 'brunch-lite' ),
	),
) );

/**
 * Radio-Buttonset Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'radio-buttonset',
	'settings'    => 'radio_buttonset_setting',
	'label'       => esc_attr__( 'Radio-Buttonset Control', 'brunch-lite' ),
	'description' => esc_attr__( 'The description here.', 'brunch-lite' ),
	'section'     => 'radio_buttonset_section',
	'default'     => 'option-2',
	'choices'     => array(
		'option-1' => esc_attr__( 'Option 1', 'brunch-lite' ),
		'option-2' => esc_attr__( 'Option 2', 'brunch-lite' ),
		'option-3' => esc_attr__( 'Option 3', 'brunch-lite' ),
	),
) );

/**
 * Radio-Image Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'radio-image',
	'settings'    => 'radio_image_setting',
	'label'       => esc_attr__( 'Radio-Image Control', 'brunch-lite' ),
	'description' => esc_attr__( 'The description here.', 'brunch-lite' ),
	'section'     => 'radio_image_section',
	'default'     => 'travel',
	'choices'     => array(
		'moto'    => 'https://jawordpressorg.github.io/wapuu/wapuu-archive/wapuu-moto.png',
		'cossack' => 'https://raw.githubusercontent.com/templatemonster/cossack-wapuula/master/cossack-wapuula.png',
		'travel'  => 'https://jawordpressorg.github.io/wapuu/wapuu-archive/wapuu-travel.png',
	),
) );

/**
 * Select Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'select',
	'settings'    => 'select_setting',
	'label'       => esc_attr__( 'Select Control', 'brunch-lite' ),
	'description' => esc_attr__( 'The description here.', 'brunch-lite' ),
	'section'     => 'select_section',
	'default'     => 'option-3',
	'choices'     => array(
		'option-1' => esc_attr__( 'Option 1', 'brunch-lite' ),
		'option-2' => esc_attr__( 'Option 2', 'brunch-lite' ),
		'option-3' => esc_attr__( 'Option 3', 'brunch-lite' ),
		'option-4' => esc_attr__( 'Option 4', 'brunch-lite' ),
		'option-5' => esc_attr__( 'Option 5', 'brunch-lite' ),
	),
) );

/**
 * Slider Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'slider',
	'settings'    => 'slider_setting',
	'label'       => esc_attr__( 'Slider Control', 'brunch-lite' ),
	'description' => esc_attr__( 'The description here.', 'brunch-lite' ),
	'section'     => 'slider_section',
	'default'     => '10',
	'choices'     => array(
		'min'  => 0,
		'max'  => 20,
		'step' => 1,
		'suffix' => 'px',
	),
) );

/**
 * Sortable control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'sortable',
	'settings'    => 'sortable_setting',
	'label'       => __( 'This is a sortable control.', 'brunch-lite' ),
	'section'     => 'sortable_section',
	'default'     => array( 'option3', 'option1', 'option4' ),
	'choices'     => array(
		'option1' => esc_attr__( 'Option 1', 'brunch-lite' ),
		'option2' => esc_attr__( 'Option 2', 'brunch-lite' ),
		'option3' => esc_attr__( 'Option 3', 'brunch-lite' ),
		'option4' => esc_attr__( 'Option 4', 'brunch-lite' ),
		'option5' => esc_attr__( 'Option 5', 'brunch-lite' ),
		'option6' => esc_attr__( 'Option 6', 'brunch-lite' ),
	),
) );

/**
 * Switch control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'switch',
	'settings'    => 'switch_setting',
	'label'       => esc_attr__( 'Switch Control', 'brunch-lite' ),
	'description' => esc_attr__( 'Description', 'brunch-lite' ),
	'section'     => 'switch_section',
	'default'     => true,
) );

/**
 * Toggle control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'toggle',
	'settings'    => 'toggle_setting',
	'label'       => esc_attr__( 'Toggle Control', 'brunch-lite' ),
	'description' => esc_attr__( 'Description', 'brunch-lite' ),
	'section'     => 'toggle_section',
	'default'     => true,
) );

/**
 * Typography Control.
 */
Kirki::add_field( 'kirki_demo', array(
	'type'        => 'typography',
	'settings'    => 'typography_setting_0',
	'label'       => esc_attr__( 'Typography Control Label', 'brunch-lite' ),
	'description' => esc_attr__( 'The full set of options.', 'brunch-lite' ),
	'section'     => 'typography_section',
	'default'     => array(
		'font-family'    => 'Roboto',
		'variant'        => 'regular',
		'font-size'      => '14px',
		'line-height'    => '1.5',
		'letter-spacing' => '0',
		'subsets'        => array( 'latin-ext' ),
		'color'          => '#333333',
		'text-transform' => 'none',
		'text-align'     => 'left',
	),
	'priority'    => 10,
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'typography',
	'settings'    => 'typography_setting_1',
	'label'       => esc_attr__( 'Typography Control Label', 'brunch-lite' ),
	'description' => esc_attr__( 'Just the font-family.', 'brunch-lite' ),
	'section'     => 'typography_section',
	'default'     => array(
		'font-family'    => 'Roboto',
	),
) );

Kirki::add_field( 'kirki_demo', array(
	'type'        => 'typography',
	'settings'    => 'typography_setting_2',
	'label'       => esc_attr__( 'Typography Control Label', 'brunch-lite' ),
	'description' => esc_attr__( 'Only font-size, line-height, letter-spacing and color.', 'brunch-lite' ),
	'section'     => 'typography_section',
	'default'     => array(
		'font-size'      => '14px',
		'line-height'    => '1.5',
		'letter-spacing' => '0',
		'color'          => '#333333',
	),
) );
